# tgpirobot - Auto-reply app for Telegram

Author: [HK4CRPRASAD](https://github.com/hk4crprasad)

**tgpirobot** lets you auto-reply to messages on Telegram when you are offline!

## Features:
- Send automatic replies
- Blocks spammers
- Includes jokes, quotes, etc.

## Usage:
- `tgpirobot -r/--run`  Run tgpirobot
- `tgpirobot -h/--help/help`  Show help message
- `tgpirobot -i/--install/install` install all necessary package
- `tgpirobot -d/--del/del`  Delete old session file for new login

**tgpirobot** is licensed under the GPL-3.0.  
See [https://github.com/hk4crprasad/tgpirobot](https://github.com/hk4crprasad/tgpirobot) for more info.
